/**
 * Default Chart Configuration.
 * This configuration applies to any chart irrespective of its type.
 */

export default {

    chart:{
        renderTo: '', //will be set later where used.
        height: 300, //setting default chart height to 300px.
        animation: false,
        marginLeft: 50,
        margingRight: 10,
        events: {},
        zoomType: "x",
        resetZoomButton: {
            position: {
                align: 'left',
                verticalAlign: 'bottom',
                x: -50,
            },
            theme: {
                fill: '#67A1D3',
                stroke: '#5395cd',
                r: 0,
                style: {
                    color: 'white'
                },
                states: {
                    hover: {
                        fill: '#3f89c8',
                        style: {
                            color: 'white'
                        }
                    }
                }
            }
        }
    },
    tooltip: {
        useHTML: false,
        borderWidth: 0,
        borderRadius: 0,
        shadow: false,
        style: {
            fontWeight: 'bold'
        },
        shared: true,
        backgroundColor: null,  //Need to set this to NULL as it defaults to rgba(255,255,255,0.85)
        hideDelay: 1,
        crosshairs: {
            width: 1.2,
            dashStyle: 'solid',
            color: '#3D3D3D'
        }
    },
    plotOptions: {
        area: {
            marker: {
                enabled: false
            },
            states: {
                hover: {
                    enabled: false
                }
            },
            dataGrouping: {
                enabled: true,
                approximation: "high",
                groupPixelWidth: 1      //This has to be in sync with plotOptions.area.lineWidth
            },

            turboThreshold: 0,
            stacking: 'normal',
            lineWidth: 1,   //This has to be in sync with plotOptions.area.dataGrouping.groupPixelWidth
            connectNulls: false
        },
        line: {
            marker: {
                enabled: false
            },
            states: {
                hover: {
                    enabled: false
                }
            },
            dataGrouping: {
                enabled: true,
                approximation: "high",
                groupPixelWidth: 1      //This has to be in sync with plotOptions.line.lineWidth
            },
            turboThreshold: 0,
            lineWidth: 1
        }
    },
    legend: {
        enabled: false
    },
    xAxis: {
        type: 'datetime',
        tickLength: 5,
        tickPixelInterval: 150,  //Defined to limit the # of ticks as the dateTimeFormat is pretty long
        minRange: 3600 * 1000,  //The min zoom range is 1 hour
        labels: {
            enabled: true
        },
        dateTimeLabelFormats: {
            millisecond: "%a %m/%e<br>%l:%M:%S %p",
            second: "%a %m/%e<br>%l:%M:%S %p",
            minute: "%a %m/%e<br>%l:%M %p",
            hour: "%a %m/%e<br>%l %p",
            day: "%a %m/%e<br>%l %p",
            week: "%e %b",
            month: "%b %y",
            year: "%Y"
        }
    },
    yAxis: {
        min: 0,
        minRange: null, //Add this value if you want to bind a minimum range on the y axis. This value can be set based on a metric type through a configuration.
        lineWidth: 1,
        gridLineWidth: 0,
        tickLength: 5,
        tickWidth: 1,
        title: {
            text: '',
            align: 'high',
            offset: 0,
            rotation: 0,
            y: -1
        }
    },
    title: {
        text: '',
        style: {
            display: 'none'
        },
    },
    credits: {
        enabled: false
    },
    loading: {
        labelStyle: {
            color: 'white'
        },
        style: {
            backgroundColor: 'gray'
        }
    },
    series : []
}
