import * as angular from 'angular';

export default class HighChartsResizer {

    static NAME: string = 'nwfHighChartsResizer';

    private chartsAttr = 'data-highcharts-chart';

    private getAllHigchartsWithinElement($element) {
        return $element.find('[' + this.chartsAttr + ']');
    }

    private getHigchartId(chartNode) {
        return chartNode.getAttribute(this.chartsAttr);
    }

    private getHighchart(chartId) {
        return angular.element('[' + this.chartsAttr + '="' + chartId + '"]').highcharts();
    }

    private reflowCharts($element) {
        for (var chart of this.getAllHigchartsWithinElement($element)) {
            this.getHighchart(this.getHigchartId(chart)).reflow();
        }
    }

    private resizeCharts($element, width: number) {
        for (var chart of this.getAllHigchartsWithinElement($element)) {
            this.getHighchart(this.getHigchartId(chart)).setSize(width, undefined, false);
        }
    }

    //resetCharts takes an $element, finds all of the charts inside it, then resizes them small, then resets them, then reflows to the container.
    public resetCharts($element) {
        //The algorithm is, I reset the size of the charts to 1, then reset it to null, shrinking it, and then reflowing to the container width.
        this.resizeCharts($element, 1);
        this.resizeCharts($element, null);
        this.reflowCharts($element);
    }

}
