import * as angular from 'angular';
import NwfHelpModule from './help/nwfHelp-module';
import NwfIcon from './icon/icon-component';
import NwfLoadingIndicator from './loading-indicator/loadingIndicator-component';
import { NwfPageAlert, NwfPageAlertFactory } from './page-alert/nwfPageAlert-directive';
import ChartComponentsModule from './chart/chart-module';
import ShellModule from './shell/shell-module';
import FormModule from './form/form-module';
import NwfModalModule from './modals/modal-module';
import NwfConfigProvider from './nwfConfig-provider';
import ElipSizer from './elipsizer/elipsizer-directive';

import ProgressIndicator from './progress-indicator/progressIndicator-component';

export default class NwfComponentsModule {

    static NAME = 'nwfComponentsModule';

    static DEPENDENCIES: Array<string> = [
        ShellModule.NAME,
        FormModule.NAME,
        NwfHelpModule.NAME,
        ChartComponentsModule.NAME,
        NwfModalModule.NAME
    ];

    private native: angular.IModule;

    constructor() {
        this.initModules();
        this.native = angular.module(NwfComponentsModule.NAME, NwfComponentsModule.DEPENDENCIES);
        this.native.provider('nwfConfig', NwfConfigProvider);
        this.native.component(NwfIcon.NAME, new NwfIcon());
        this.native.component(NwfLoadingIndicator.NAME, new NwfLoadingIndicator());
        this.native.directive(NwfPageAlert.NAME, NwfPageAlertFactory);
        this.native.component(ProgressIndicator.NAME, new ProgressIndicator());
        this.native.directive('nwfElipsizeContents', ElipSizer);
        /* i18next  format filter */

        this.native.filter('i18nextFormat', ['$i18next', function ($i18next) {
            return function (key, formatType: string) {
                return $i18next.i18n.format(key, formatType);
            };
        }])
    }

    initModules() {
        new ShellModule();
        new FormModule();
        new NwfHelpModule();
        new ChartComponentsModule();
        new NwfModalModule();
    }
}
