import NwfValidator from '../nwfValidator';

class IsSameValidatorController extends NwfValidator {

    isSame: string;
    masterElement: HTMLInputElement;

    static $inject = ['$element', '$i18next'];

    constructor(private $element: ng.IAugmentedJQuery, private $i18next) {
        super($element);
        this.invalidMessage = this.invalidMessage || $i18next.t('nwfjs:isSameInvalidMessage');
        this.emptyMessage = this.emptyMessage || $i18next.t('nwfjs:emptyMessage');
    }

    $onInit() {
        //I connect events to the masterElement so if it changes somehow, I reset and revalidate MY (this) validity, and trigger validation when the master changes
        this.masterElement = <HTMLInputElement>document.getElementById(this.isSame);
        var inputHandler = this.resetCustomValidity.bind(this);
        this.masterElement.addEventListener('input', inputHandler);
        var blurHandler = () => {
            this.$element.trigger('focus');
            if (this.$element.get(0)['hasBeenBlurred']) {
                this.$element.trigger('blur');
            }
        };
        this.masterElement.addEventListener('blur', blurHandler);
        this.$element.on('$destroy', () => {
            this.masterElement.removeEventListener('input', inputHandler);
            this.masterElement.removeEventListener('blur', blurHandler);
        });
    }

    invalidHandler() {
        if (!this.myEl.value) {
            this.myEl.setCustomValidity(this.emptyMessage);
        } else if (this.myEl.value !== this.masterElement.value) {
            this.myEl.setCustomValidity(this.invalidMessage);
        } else {
            this.myEl.setCustomValidity('');
        }
    }

}

export class IsSameValidator {
    static NAME = 'isSame';
    bindToController = {
        isSame: '@',
        emptyMessage: '@?',
        invalidMessage: '@?'
    };
    restrict = 'A';
    controller = IsSameValidatorController;
    controllerAs = 'sameCtrl';
}

// export factory function
export function IsSameValidatorFactory(): IsSameValidator {
    return new IsSameValidator();
}
